@@ -1,5 +1,6 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992 Free Software Foundation, Inc.
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002
+   Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -18,13 +19,12 @@ You should have received a copy of the GNU General Public License along
 with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
-#include <stdio.h>
-#include <string.h>
+#include "lib.h"
+
 #include <assert.h>
 #include <stdlib.h>
 #include <errno.h>
 #include "font.h"
-#include "lib.h"
 #include "searchpath.h"
 #include "device.h"
 #include "defs.h"
@@ -39,6 +39,7 @@ int font::vert = 1;
 int font::unitwidth = 0;
 int font::paperwidth = 0;
 int font::paperlength = 0;
+const char *font::papersize = 0;
 int font::biggestfont = 0;
 int font::spare2 = 0;
 int font::sizescale = 1;
