@@ -31,8 +31,10 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #include "refid.h"
 #include "search.h"
 
+/* for isatty() */
+#include "posix.h"
+
 extern "C" {
-  int isatty(int);
   const char *Version_string;
 }
 
